==> moyoung_ble_plugin-1.1.6.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/method/OTAController.java <==
package com.moyoung.moyoung_ble_plugin.method;

import static com.moyoung.moyoung_ble_plugin.ChannelNames.EVENT_FIRMWARE_UPGRADE;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.ota.hs.HsDfuController;
import com.crrepa.ble.ota.jieli.JieliDfuController;
import com.crrepa.ble.ota.sifli.SifliDfuController;
import com.moyoung.moyoung_ble_plugin.event.ConnEveChlRegister;
import com.moyoung.moyoung_ble_plugin.event.FileFirmwareUpgradeHandler;

import io.flutter.plugin.common.MethodCall;

public class OTAController {
    private int type;
    private FileFirmwareUpgradeHandler handler;
    private MethodCall call;
    private CRPBleConnection bleConnection;
    public static final int START_HS_OTA = 1;
    public static final int START_RTK_OTA = 2;
    public static final int START_OTA = 3;
    public static final int START_DEFAULT_OTA = 4;

    public OTAController(int type, ConnEveChlRegister connEveChlRegister, MethodCall call, CRPBleConnection bleConnection) {
        this.type = type;
        this.handler = (FileFirmwareUpgradeHandler) connEveChlRegister.getLazyEveChlHandler(EVENT_FIRMWARE_UPGRADE);
        this.call = call;
        this.bleConnection = bleConnection;
    }

    public OTAController() {
    }

    public OTAController(int type) {
        this.type = type;
    }

    public OTAController(ConnEveChlRegister connEveChlRegister) {
        this.handler = (FileFirmwareUpgradeHandler) connEveChlRegister.getLazyEveChlHandler(EVENT_FIRMWARE_UPGRADE);
    }

    public void startOTA() {
        if (this.handler != null) {

            switch (this.type) {
                case START_HS_OTA:
                    this.handler.setHsLazyConnListener(call);
                case START_RTK_OTA:
                    this.handler.setRtkUpgradeListener(call);
                default:
                    this.handler.setConnListener(bleConnection, call);
            }
        }
    }

    public void abortOTA() {
        if (this.handler != null) {

            switch (this.type) {
                case START_HS_OTA:
                    HsDfuController hsDfuController = HsDfuController.getInstance();
                    hsDfuController.abort();
                default:
                    bleConnection.abortFirmwareUpgrade();
            }
        }
    }

    public void sifliStartOTA(String address) {
        if (this.handler != null) {
            SifliDfuController controller = new SifliDfuController();
            this.handler.setSifliUpgradeListener(controller);
            controller.start(address);
        }
    }

    public void jieliStartOTA() {
        if (this.handler != null) {
            JieliDfuController controller = new JieliDfuController();
            this.handler.setJieliUpgradeListener(controller);
            controller.start();
        }
    }

    public void jieliAbortOTA() {
        if (this.handler != null) {
            JieliDfuController controller = new JieliDfuController();
            controller.abort();
        }
    }
}

==> moyoung_ble_plugin-1.2.7.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/method/OTAController.java <==
package com.moyoung.moyoung_ble_plugin.method;

import static com.moyoung.moyoung_ble_plugin.ChannelNames.EVENT_FIRMWARE_UPGRADE;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.ota.hs.HsDfuController;
import com.crrepa.ble.ota.jieli.JieliDfuController;
import com.crrepa.ble.ota.sifli.SifliDfuController;
import com.moyoung.moyoung_ble_plugin.event.ConnEveChlRegister;
import com.moyoung.moyoung_ble_plugin.event.FileFirmwareUpgradeHandler;

import java.io.File;

import io.flutter.plugin.common.MethodCall;

public class OTAController {
    private int type;
    private FileFirmwareUpgradeHandler handler;
    private MethodCall call;
    private CRPBleConnection bleConnection;
    public static final int START_OTA = 0;
    public static final int START_NORDIC_OTA = 1;
    public static final int START_HS_OTA = 2;
    public static final int START_RTK_OTA = 3;
    public static final int START_GOODIX_OTA = 4;

    public OTAController(int type, ConnEveChlRegister connEveChlRegister, MethodCall call, CRPBleConnection bleConnection) {
        this.type = type;
        this.handler = (FileFirmwareUpgradeHandler) connEveChlRegister.getLazyEveChlHandler(EVENT_FIRMWARE_UPGRADE);
        this.call = call;
        this.bleConnection = bleConnection;
    }

    public OTAController() {
    }

    public OTAController(int type) {
        this.type = type;
    }

    public OTAController(ConnEveChlRegister connEveChlRegister) {
        this.handler = (FileFirmwareUpgradeHandler) connEveChlRegister.getLazyEveChlHandler(EVENT_FIRMWARE_UPGRADE);
    }

    public void startOTA() {
        if (this.handler != null) {

            switch (this.type) {
                case START_HS_OTA:
                    this.handler.setHsLazyConnListener(call);
                    break;
                case START_RTK_OTA:
                    this.handler.setRtkUpgradeListener(call);
                    break;
                case START_NORDIC_OTA:
                    this.handler.setFirmwareUpgrade(bleConnection, false, call);
                    break;
                case START_GOODIX_OTA:
                    this.handler.setFirmwareUpgrade(bleConnection, true, call);
                    break;
            }
        }
    }

    public void abortOTA() {
        if (this.handler != null) {

            switch (this.type) {
                case START_HS_OTA:
                    HsDfuController hsDfuController = HsDfuController.getInstance();
                    hsDfuController.abort();
                    break;
                case START_NORDIC_OTA:
                case START_GOODIX_OTA:
                    bleConnection.abortFirmwareUpgrade();
                    break;
            }
        }
    }

    public void sifliStartOTA(String address) {
        if (this.handler != null) {
            SifliDfuController controller = new SifliDfuController();
            this.handler.setSifliUpgradeListener(controller);
            controller.start(address);
        }
    }

    public void jieliStartOTA(String pathname) {
        if (this.handler != null) {
            JieliDfuController controller = new JieliDfuController();
            this.handler.setJieliUpgradeListener(controller);
            File file = new File(pathname);
            if (file.exists()) {
                controller.start(file);
            }
        }
    }

    public void jieliAbortOTA() {
        if (this.handler != null) {
            JieliDfuController controller = new JieliDfuController();
            controller.abort();
        }
    }
}
